# Power Analysis, Arabic Predictability Study, October 21st, 2020
# Versions: R: 4.0.2, lme4: 1.1-25, simr: 1.0.5, plyr: 1.8.6
# Power analysis based on the means (and sds) of Frisson et al., (2017) Experiment 1's
# predictable and unpredictable conditions (we collapsed the context conditions).

###### Skipping Probability ######
# Predictable = 25 (16), Unpredictable = 22 (15),

# Clean workspace
rm(list=ls())

# Load packages and data files
library(lme4)
library(simr)
library(plyr)

# Prepare file for data simulation (1 factor x 2 levels)
pp_1 <- factor(1:40)
pp_2 <- rep(pp_1, each=72)
stim_1 <- 1:72
version <- rep(1:2, each= 72)
simdata_1 <- data.frame(version, pp=pp_2, stim=stim_1)
simdata_1$cond = 0
simdata_1$cond[simdata_1$version=="1"] <- c("Predictable", "Unpredictable")
simdata_1$cond[simdata_1$version=="2"] <- c("Unpredictable", "Predictable")
simdata <- data.frame(pp=pp_2, stim=stim_1, condition=simdata_1$cond)

# Authors removed 2.5% of trials, this will leave 2808 trials out of the 2880 trials.
simdata <-simdata[sample(NROW(simdata), NROW(simdata)*(1 - 0.025)),]

# make sure all the variables are from the correct class
simdata$pp = as.factor(simdata$pp)
simdata$stim = as.factor(simdata$stim)
simdata$condition = as.factor(simdata$condition)
str(simdata)

# fixed intercept and slope
# first value is the mean of all values (Mean = 24), 
# the second value is the effect size, which is the difference between the two values (UP - P = -3),

b = c(24, -3)

# random intercept variance
# For this I'm putting in the standard deviation for the first condition
V1 <- 16

# residual variance
# For this I'm putting the average standard deviation for all values
s <- 16

# run the model
model1 <- makeLmer(y ~ condition + (1|pp), fixef=b, VarCorr=V1, sigma=s, data=simdata)
summary(model1)

# here we run 200 (Monte Carlo) simulations, as suggested by Brysbaert and Stevens (2018).
powercalculation  <- powerSim(model1, nsim=200, fixed("condition"))
powercalculation

(powercalculation2 <-powerCurve(model1, along="pp", nsim=200))
plot(powercalculation2)

###### First fixation duration ######
# Predictable = 213 (27), Unpredictable = 222 (32),

# Clean workspace
rm(list=ls())

# Load packages and data files
library(lme4)
library(simr)
library(plyr)

# Prepare file for data simulation (1 factor x 2 levels)
pp_1 <- factor(1:40)
pp_2 <- rep(pp_1, each=72)
stim_1 <- 1:72
version <- rep(1:2, each= 72)
simdata_1 <- data.frame(version, pp=pp_2, stim=stim_1)
simdata_1$cond = 0
simdata_1$cond[simdata_1$version=="1"] <- c("Predictable", "Unpredictable")
simdata_1$cond[simdata_1$version=="2"] <- c("Unpredictable", "Predictable")
simdata <- data.frame(pp=pp_2, stim=stim_1, condition=simdata_1$cond)

# Authors removed 2.5% of trials, this will leave 2808 trials out of the 2880 trials.
simdata <-simdata[sample(NROW(simdata), NROW(simdata)*(1 - 0.025)),]

# make sure all the variables are from the correct class
simdata$pp = as.factor(simdata$pp)
simdata$stim = as.factor(simdata$stim)
simdata$condition = as.factor(simdata$condition)
str(simdata)

# fixed intercept and slope
# first value is the mean of all values (Mean = 218), 
# the second value is the effect size, which is the difference between the two values (UP - P = 9),

b = c(218, 9)

# random intercept variance
# For this I'm putting in the standard deviation for the first condition
V1 <- 27

# residual variance
# For this I'm putting the average standard deviation for all values
s <- 30

# run the model
model1 <- makeLmer(y ~ condition + (1|pp), fixef=b, VarCorr=V1, sigma=s, data=simdata)
summary(model1)

# here we run 200 (Monte Carlo) simulations, as suggested by Brysbaert and Stevens (2018).
powercalculation  <- powerSim(model1, nsim=200, fixed("condition"))
powercalculation

(powercalculation2 <-powerCurve(model1, along="pp", nsim=200))
plot(powercalculation2)


###### Gaze duration ######
# Predictable = 225 (33), Unpredictable = 236 (36),

# Clean workspace
rm(list=ls())

# Load packages and data files
library(lme4)
library(simr)
library(plyr)

# Prepare file for data simulation (1 factor x 2 levels)
pp_1 <- factor(1:40)
pp_2 <- rep(pp_1, each=72)
stim_1 <- 1:72
version <- rep(1:2, each= 72)
simdata_1 <- data.frame(version, pp=pp_2, stim=stim_1)
simdata_1$cond = 0
simdata_1$cond[simdata_1$version=="1"] <- c("Predictable", "Unpredictable")
simdata_1$cond[simdata_1$version=="2"] <- c("Unpredictable", "Predictable")
simdata <- data.frame(pp=pp_2, stim=stim_1, condition=simdata_1$cond)

# Authors removed 2.5% of trials, this will leave 2808 trials out of the 2880 trials.
simdata <-simdata[sample(NROW(simdata), NROW(simdata)*(1 - 0.025)),]

# make sure all the variables are from the correct class
simdata$pp = as.factor(simdata$pp)
simdata$stim = as.factor(simdata$stim)
simdata$condition = as.factor(simdata$condition)
str(simdata)

# fixed intercept and slope
# first value is the mean of all values (Mean = 231), 
# the second value is the effect size, which is the difference between the two values (UP - P = 11),

b = c(231, 11)

# random intercept variance
# For this I'm putting in the standard deviation for the first condition
V1 <- 33

# residual variance
# For this I'm putting the average standard deviation for all values
s <- 35

# run the model
model1 <- makeLmer(y ~ condition + (1|pp), fixef=b, VarCorr=V1, sigma=s, data=simdata)
summary(model1)

# here we run 200 (Monte Carlo) simulations, as suggested by Brysbaert and Stevens (2018).
powercalculation  <- powerSim(model1, nsim=200, fixed("condition"))
powercalculation

(powercalculation2 <-powerCurve(model1, along="pp", nsim=200))
plot(powercalculation2)
