# Arabic Word Predictability, 18.07.2021
# Versions: R: 4.0.2, lme4: 1.1-27.1, simr: 1.0.5, plyr: 1.8.6,
# languageR: 1.5.0, Matrix: 1.3-4, lattice: 0.20-44, MASS: 7.3-54

####  Load packages and data files ####
library(languageR)
library(Matrix)
library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())
datafile = read.csv(file.choose(), sep = ",", dec = ".")
colnames(datafile)

####  Specify which column your participant, stimuli and condition are in ####
col.subject = 1
col.stim = 2
col.condition = 3


####  Set exclusion criteria
crit = 2.5

# choose dependent variable
measure = "GD"

# add to dataframe
datafile$depvar = datafile[,measure]


####  Assign the correct class ####

# Work out which columns the fixed and random factors are in
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)


####  Inspect and double check ####
str(datafile)
summary(datafile)

#find means (per participant, per condition)
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt

#find sds (per participant, per condition)
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt

####  Remove outliers ####

nrcolumns = ncol(datafile)   # We'll be using this for cleanup later

#let's first have a look
head(datafile)

# make a new datafile with fixation durations > 0 ms
datafile_2 = datafile[datafile$depvar > 0, ]
head(datafile_2)
datafile_2 = datafile

#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile_2$depvar, list(datafile_2$pp, datafile_2$condition), mean, na.rm = T)
mean.matrix

#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile_2$depvar, list(datafile_2$pp, datafile_2$condition), sd, na.rm = T)
sd.matrix

#add this data to the actual dataframe
for(i in 1:nrow(datafile_2)){datafile_2$mean.sc[i] = mean.matrix[datafile_2$pp[i],datafile_2$condition[i]]}
for(i in 1:nrow(datafile_2)){datafile_2$sd.sc[i] = sd.matrix[datafile_2$pp[i],datafile_2$condition[i]]}

#calculate z-scores
for(i in 1:nrow(datafile_2)) {datafile_2$zscore[i] = (datafile_2$depvar[i] - datafile_2$mean.sc[i])/datafile_2$sd.sc[i]}

# assign a zero value to cells with only 1 observation
datafile_2$zscore[is.na(datafile_2$zscore)] = 0

#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = datafile_2[abs(datafile_2$zscore) < 2.5,]

#you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]

datafile_2 = result    # insert the name from the datafile coming from the cleanup on the right
datafile = datafile_2
head(datafile)


####  Descriptive statistics summary ####

grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.sd=apply(sd.tt,2,mean, na.rm = T)
grand.se=grand.sd/sqrt(40)  ## this number is the total number of participants from your data, so it is changable.
summary.ds = rbind(grand.mean, grand.sd, grand.se)
summary.ds

####  Setting contrasts and table of means ####

contrasts(datafile$condition) <- contr.sdif(2)
(table1 <- ddply(datafile, .(predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))

####  LME Models  ####

# Model 1 - This model converged for the following measure: Experiment 1-FFD, 
depvar.lmeM1 = lmer(depvar ~ predictability  + (1 + predictability|participant) + (1 + predictability|item), datafile)
print(depvar.lmeM1, corr = FALSE)
summary(depvar.lmeM1, corr = FALSE)

# Model 2 - - This model converged for the following measure: Experiment 1-GD, 
depvar.lmeM2 = lmer(depvar ~ predictability  + (1 + predictability|participant) + (1 |item), datafile)
print(depvar.lmeM2, corr = FALSE)
summary(depvar.lmeM2, corr = FALSE)

# Model 3
depvar.lmeM3 = lmer(depvar ~ predictability  + (1 |participant) + (1 + predictability|item), datafile)
print(depvar.lmeM3, corr = FALSE)
summary(depvar.lmeM3, corr = FALSE)

# Model 4
depvar.lmeM4 = lmer(depvar ~ predictability  + (1 |participant) + (1 |item), datafile)
print(depvar.lmeM4, corr = FALSE)
summary(depvar.lmeM4, corr = FALSE)

# Use this code when the Singularity error arises due to a correlation.
datafile$predictability<-ifelse(datafile$condition=="Predictable",-1/2,1/2)

####  binominal variables ####
  
  ####  Load packages and data files ####
library(languageR)
library(Matrix)
library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())
datafile = read.csv(file.choose(), sep = ",", dec = ".")
colnames(datafile)


####  Specify which column your participant, stimuli and condition are in ####
col.subject = 1
col.stim = 2
col.condition = 3

# choose dependent variable
measure = "SKIP"

# add to dataframe
datafile$depvar = datafile[,measure]


####  Assign the correct class ####

# Work out which columns the fixed and random factors are in
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)


####  Inspect and double check ####
str(datafile)
summary(datafile)

#find means (per participant, per condition)
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt

#find sds (per participant, per condition)
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt

####  Descriptive statistics summary ####

grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.sd=apply(sd.tt,2,mean, na.rm = T)
grand.se=grand.sd/sqrt(40)  ## this number is the total number of participants from your data, so it is changable.
summary.ds = rbind(grand.mean, grand.sd, grand.se)
summary.ds

####  Setting contrasts and table of means ####

contrasts(datafile$condition) <- contr.sdif(2)
(table1 <- ddply(datafile, .(predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))

#### GLME Models  ####

# Model 1
depvar.glmeM1 = glmer(depvar ~  predictability + (1 + predictability|participant) + (1 + predictability|item), datafile, family = binomial)
print(depvar.glmeM1, corr = FALSE)
summary(depvar.glmeM1, corr = FALSE)

# Model 2
depvar.glmeM2 = glmer(depvar ~  predictability + (1 + predictability|participant) + (1 |item), datafile, family = binomial)
print(depvar.glmeM2, corr = FALSE)
summary(depvar.glmeM2, corr = FALSE)

# Model 3
depvar.glmeM3 = glmer(depvar ~  predictability + (1 |participant) + (1 + predictability|item), datafile, family = binomial)
print(depvar.glmeM3, corr = FALSE)
summary(depvar.glmeM3, corr = FALSE)

# Model 4
depvar.glmeM4 = glmer(depvar ~  predictability + (1 |participant) + (1 |item), datafile, family = binomial)
print(depvar.glmeM4, corr = FALSE)
summary(depvar.glmeM4, corr = FALSE)
